//TODO 通讯录接口
/**
 * 通讯录接口
 */
var nativeCommon = {
    /**
     * 通讯录 
     * 调用方法：nativeCommon.contacts.getContact(function callBack(name, phoneNumber));
     */
    contacts:{
        getContact:function(callBack){
            switch (plus.os.name){
                case "iOS":
                    if (plus.device.model === "iPhoneSimulator") {
                        //模拟器
                        nativeCommon.contacts.ios.visitContacts(function(name, phoneNumber){
                            var phone = phoneNumber.replace('+86', '').replace(/\s/g, '').replace(/-/g, '');
                            callBack(name, phone);
                        });
                    } else {
                        //真机
                        nativeCommon.contacts.ios.visitAddressBook(function(name, phoneNumber){
                            var phone = phoneNumber.replace('+86', '').replace(/\s/g, '').replace(/-/g, '');
                            callBack(name, phone);
                        });
                    }
                    break;
                case "Android":
                    nativeCommon.contacts.android.visitContacts(function(name, phoneNumber){
                        var phone = phoneNumber.replace('+86', '').replace(/\s/g, '').replace(/-/g, '');
                        callBack(name, phone);
                    });
                    break;
                default:
                    break;
            }
        },
        ios:{//供iOS系统调用
            /**
             * 访问通讯录，将获取的联系人信息通过callBack返回
             * 仅限模拟器使用（Native.js 的bug）
             * @param {Object} callBack回调
             */
            visitContacts: function(callBack){
                var contactPickerVC = plus.ios.newObject("CNContactPickerViewController");
                //实现代理方法【- (void)contactPicker:(CNContactPickerViewController *)picker didSelectContact:(CNContact *)contact;】
                //同时生成遵守CNContactPickerDelegate协议的代理对象delegate
                var delegate = plus.ios.implements("CNContactPickerDelegate", {
                    "contactPicker:didSelectContact:":function(picker, contact){
                        console.log(JSON.stringify(picker));
                        console.log(JSON.stringify(contact));
                        //姓名
                        var name = "";
                        //姓氏
                        var familyName = contact.plusGetAttribute("familyName");
                        //名字
                        var givenName = contact.plusGetAttribute("givenName");
                        name = familyName+givenName;
                        //电话号码
                        var phoneNo = "";
                        var phoneNumbers = contact.plusGetAttribute("phoneNumbers");
                        if (phoneNumbers.plusGetAttribute("count") > 0) {
                            var phone = phoneNumbers.plusGetAttribute("firstObject");
                            var phoneNumber = phone.plusGetAttribute("value");
                            phoneNo = phoneNumber.plusGetAttribute("stringValue");
                        }
                        if(callBack){
                            callBack(name, phoneNo);
                        }
                    }
                });
                //给通讯录控制器contactPickerVC设置代理
                plus.ios.invoke(contactPickerVC, "setDelegate:", delegate);
                //获取当前UIWebView视图
                var currentWebview = plus.ios.currentWebview();
                //根据当前UIWebView视图获取当前控制器
                var currentVC = nativeCommon.contacts.ios.getViewControllerByView(currentWebview);
                //由当前控制器present到通讯录控制器
                plus.ios.invoke(currentVC, "presentViewController:animated:completion:", contactPickerVC, true, null);
            },
            /**
             * 访问通讯录，将获取的联系人信息通过callBack返回
             * 仅限真机使用（Native.js 的bug）
             * @param {Object} callBack
             */
            visitAddressBook:function(callBack){
                var peoplePickerNavController = plus.ios.newObject("ABPeoplePickerNavigationController");
                //实现代理方法【- (void)peoplePickerNavigationController:(ABPeoplePickerNavigationController *)peoplePicker didSelectPerson:(ABRecordRef)person;】
                //同时生成遵守ABPeoplePickerNavigationControllerDelegate协议的代理对象peoplePickerDelegate
                var peoplePickerDelegate = plus.ios.implements("ABPeoplePickerNavigationControllerDelegate", {
                    "peoplePickerNavigationController:didSelectPerson:":function(peoplePicker, person){
                        //这里的peoplePicker竟然是CNContact实例对象，person是undefined
                        console.log(JSON.stringify(peoplePicker));
                        console.log(JSON.stringify(person));
                        console.log(typeof person);
                        
                        //所以之前的代码不用改
                        var contact = peoplePicker;
                        //姓名
                        var name = "";
                        //姓氏
                        var familyName = contact.plusGetAttribute("familyName");
                        //名字
                        var givenName = contact.plusGetAttribute("givenName");
                        name = familyName+givenName;
                        //电话号码
                        var phoneNo = "";
                        var phoneNumbers = contact.plusGetAttribute("phoneNumbers");
                        if (phoneNumbers.plusGetAttribute("count") > 0) {
                            var phone = phoneNumbers.plusGetAttribute("firstObject");
                            var phoneNumber = phone.plusGetAttribute("value");
                            phoneNo = phoneNumber.plusGetAttribute("stringValue");
                        }
                        if (callBack) {
                            callBack(name, phoneNo);
                        }
                    }
                });
                //给通讯录控制器peoplePickerNavController设置代理
                plus.ios.invoke(peoplePickerNavController, "setPeoplePickerDelegate:", peoplePickerDelegate);
                //获取当前UIWebView视图
                var currentWebview = plus.ios.currentWebview();
                //根据当前UIWebView视图获取当前控制器
                var currentVC = nativeCommon.contacts.ios.getViewControllerByView(currentWebview);
                //由当前控制器present到通讯录控制器
                plus.ios.invoke(currentVC, "presentViewController:animated:completion:", peoplePickerNavController, true, null);
            },
            /**
             * 根据view获取到当前控制器
             * @param {Object} view
             */
            getViewControllerByView: function(view){
                if (plus.os.name != "iOS") {
                    return null;
                }
                //UIViewController类对象
                var UIViewController = plus.ios.invoke("UIViewController", "class");
                while(view){
                    var responder = plus.ios.invoke(view, "nextResponder");
                    if (plus.ios.invoke(responder, "isKindOfClass:", UIViewController)) {
                        return responder;
                    }
                    view = plus.ios.invoke(view, "superview");
                }
                return null;
            }
        },
        android:{//供android系统调用
            visitContacts:function(callBack){
                var REQUESTCODE = 1000;
                main = plus.android.runtimeMainActivity();
                var Intent = plus.android.importClass('android.content.Intent');
                var ContactsContract = plus.android.importClass('android.provider.ContactsContract');
                var intent = new Intent(Intent.ACTION_PICK, ContactsContract.Contacts.CONTENT_URI);
                main.onActivityResult = function(requestCode, resultCode, data) { 
                    if (REQUESTCODE == requestCode) {
                        var phoneNumber = "";
                        var resultString = "";
                        var context = main;
                        plus.android.importClass(data);
                        var contactData = data.getData();
                        var resolver = context.getContentResolver();
                        plus.android.importClass(resolver);
                        var cursor = resolver.query(contactData, null, null, null, null);
                        plus.android.importClass(cursor);
                        cursor.moveToFirst();
                        //姓名
                        var givenName = cursor.getString(cursor.getColumnIndex(ContactsContract.Contacts.DISPLAY_NAME)) || "";
                        var contactId = cursor.getString(cursor.getColumnIndex(ContactsContract.Contacts._ID));
                        var pCursor = resolver.query(ContactsContract.CommonDataKinds.Phone.CONTENT_URI, null, ContactsContract.CommonDataKinds.Phone.CONTACT_ID + " = " + contactId, null, null);
                        if (pCursor.moveToNext()) {
                                phoneNumber =   pCursor.getString( pCursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER));
                        }
                        if (callBack) {
                                callBack(givenName, phoneNumber);
                        }
                        cursor.close();
                        pCursor.close();
                    }
                };
                main.startActivityForResult(intent, REQUESTCODE);
            }
        }
    }
}
// TODO 调用二维码接口
var scan = null; //扫描对象 
function getqrccodeid(el){
	var height = window.innerHeight + 'px'; //获取页面实际高度    
	var width = window.innerWidth + 'px';  
	document.getElementById(el).style.height = height;  
	document.getElementById(el).style.width = width;    
	mui.plusReady(function() { //通过mui初始化扫描  
	    mui.init();  
		try{
			var filters;  
			//自定义的扫描控件样式    
			var styles = { 
				frameColor: "#29E52C", 
				scanbarColor: "#29E52C",
				background:"rgba(255,255,255,-20)",
			};
			scan = new plus.barcode.Barcode(el,filters,styles);
			scan.onmarked = onmarked;
			scan.onneror=onneror; //扫描错误
			scan.start();//开始扫描
		}catch(e){
			mui.toast('出现错误' + e);
		}
	});
}
function getqrccodeidForCallBack(el, callBack, errorCallBack){
	var height = window.innerHeight + 'px'; //获取页面实际高度    
	var width = window.innerWidth + 'px';  
	document.getElementById(el).style.height = height;  
	document.getElementById(el).style.width = width;    
	mui.plusReady(function() { //通过mui初始化扫描  
	    mui.init();  
		try{
			var filters;  
			//自定义的扫描控件样式    
			var styles = { 
				frameColor: "#29E52C", 
				scanbarColor: "#29E52C",
				background:"rgba(255,255,255,-20)",
			};
			scan = new plus.barcode.Barcode(el,filters,styles);
			scan.onmarked = (callBack != undefined && callBack != null && callBack != "") ? callBack : onmarked;
			scan.onneror = (errorCallBack != undefined && errorCallBack != null && errorCallBack != "") ? errorCallBack : onneror;
			scan.start();//开始扫描
		}catch(e){
			mui.toast('出现错误' + e);
		}
	});
}
function onneror(e){
		alert(e);
}
function onmarked(type,result){
		var text="";
		switch(type){
			case plus.barcode.QR:  
				text = 'QR: ';  
				 break;  
			case plus.barcode.EAN13:  
				  text = 'EAN13: ';  
				   break;  
			case plus.barcode.EAN8:  
				   text = 'EAN8: ';  
				   break;
		}
		alert( text+result ); //扫描成功回调 	
}
// 相册识别二维码
function scanPicture(){
	plus.gallery.pick(function(path) {  
		plus.barcode.scan(path, onmarked, function(error) {  
				mui.toast("无法识别此图片");  
		});  
		}, function(err) {  
			 plus.nativeUI.alert("如果图片无法识别，请用扫描上传");  
	}); 
}
function scanPictureForCallBack(callBack){
	plus.gallery.pick(function(path) {  
			if (callBack != undefined && callBack != null && callBack != "") {
				plus.barcode.scan(path, callBack, function(error) {  
					mui.toast("无法识别此图片");  
				});
			} else {
				plus.barcode.scan(path, onmarked, function(error) {  
						mui.toast("无法识别此图片");  
				}); 
			}
		}, function(err) {  
			 plus.nativeUI.alert("如果图片无法识别，请用扫描上传");  
		}); 
}
//返回关闭扫描控件
function goReturn(){
		scan.cancel();
		scan.close();//关闭条码识别控件
		plus.webview.currentWebview().close('none');  
		mui.back();
}

//TODO 照片选择接口
/**
 * 照片选择接口
 * @param {Object} params
 */
function IChooseImage(params){
	var isZip = params.isZip;//拍照是否压缩
	var isSave = params.isSave;//是否保存到本地
	var callBack = params.callBack;//回调函数
	
	plus.nativeUI.actionSheet({
		cancel: "取消",
		buttons: [{
			title: "拍照"
		}, {
			title: "从相册中选择"
		}]
	}, function(e) { //1 是拍照  2 从相册中选择  
		switch(e.index) {
			case 1:
				appendByCamera(isZip,isSave,callBack);
				break;
			case 2:
				appendByGallery(callBack);
				break;
		}
	});
}

// 从相册添加文件
function appendByGallery(callBack) {
	plus.gallery.pick(function(path) {
		callBack(path);
	});
}

// 拍照添加文件
function appendByCamera(isZip,isSave,callBack) {
	var cameraObj = plus.camera.getCamera();
    cameraObj.captureImage(function(e){
    	if(isZip == "1"){
    		compressImage(e,isSave,callBack);//压缩文件
    	} else {
    		plus.io.resolveLocalFileSystemURL(e, function(entry) {
				var path = entry.toLocalURL();
				callBack(path);
			}, function(e) {
				mui.toast("读取拍照文件错误：" + e.message);
			});
    	}
        
    }, function(e){
        console.log('取消拍照');
    }, {
        filename:'_doc/pic/',
        index:1
    });
}

//压缩图片
function compressImage(path,isSave,callBack) {
	plus.zip.compressImage({
		src: path,
		dst: path,
		overwrite: true,
		quality: 60,
		rotate: 90
	}, function(event) {
		var _src = event.target;
		try{
			if(isSave == "1"){
				plus.gallery.save(_src, function(evt) {
					console.log("图片保存本地成功"+_src)
				}, function(err) {
					console.log(err)
				});
			}
		}catch(e){
			console.log(e);
		}
		callBack(_src);
	}, function(err) {
		mui.toast("压缩文件错误：" + err.message);
	});
}

//TODO 开始录音接口
/**
 * 调用后开始录音，如果重复调用则以最后一次调用为开始时间进行录音
 * callBack 回调方法
 * fineName 文件名称
 */
var _appFilePath = "/storage/emulated/0/yxbdata/";
var _record;
function ISoundRecStart(callBack,fileName){
	try{
		if(plus.audio == undefined) {
			mui.toast("Device not ready please wait!");
			return;
		}
		_record = plus.audio.getRecorder();
		///storage/emulated/0/yxbdata/audio/
		///sdcard/
		if(fileName == null || fileName == undefined) {
			fileName = "";
		}
		_record.record( {filename:_appFilePath+"audio/"+fileName}, function (recordFile) {
			console.log(recordFile);
			callBack(recordFile);
		}, function (e) {
			mui.toast("Audio record failed:" + e.message);
		} );
		mui.toast("开始录音...");
	}catch(e){
		mui.toast("Audio record failed:" + e.message);
	}
}

//TODO 结束录音接口
/**
 * 结束录音，调用后执行开始录音方法中的回调方法
 */
function ISoundRecStop(){
	try{
		_record.stop();
		//mui.toast("结束录音");
	}catch(e){
		//mui.toast("Audio record failed:" + e.message);
		console.log(e);
	}
}

//TODO 播放录音接口
/**
 * 播放录音接口
 * recordFile 文件路径
 */
var _player;
function IPlaySound(recordFile){
	if(plus.audio == undefined) {
		mui.toast("Device not ready please wait!");
		return;
	}
	_player = plus.audio.createPlayer(recordFile);
	_player.play(function() {
		//播放成功
	}, function(e) {
		mui.toast("Audio play error: " + e.message);
	});
}
